3.1.9. biosimulators_utils.plot package — BioSimulators utils 0.1.95 documentation

# 3.1.9. biosimulators_utils.plot package

## 3.1.9.1. Submodules

## 3.1.9.2. biosimulators_utils.plot.data_model module

Data model for plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-06

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

class biosimulators_utils.plot.data_model.PlotFormat(value)

  Bases: `str`, `enum.Enum`

  Format of a report

  jpg = 'jpg'
  pdf = 'pdf'
  png = 'png'
  svg = 'svg'

## 3.1.9.3. biosimulators_utils.plot.io module

Methods for generating SED plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2020-12-23

Copyright

  2020, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.plot.io.write_plot_2d(plot, data_generator_results, base_path, rel_path, format=PlotFormat.pdf, style='seaborn-paper')

  Generate a 2D plot

  Parameters

    - plot (`Plot2D`) – description of plot

    - data_generator_results (`DataGeneratorResults`) – results of data generators

    - base_path (`str`) – base path to save plot

    - rel_path (`str`) – path to save results relative to `base_path`

    - format (`PlotFormat`, optional) – format

    - style (`str`, optional) – matplotlib style

biosimulators_utils.plot.io.write_plot_3d(plot, data_generator_results, base_path, rel_path, format=PlotFormat.pdf, style='seaborn-paper', colormaps=[<matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>, <matplotlib.colors.ListedColormap object>])

  Generate a 3D plot

  Parameters

    - plot (`Plot3D`) – description of plot

    - data_generator_results (`DataGeneratorResults`) – results of data generators

    - base_path (`str`) – base path to save plot

    - rel_path (`str`) – path to save results relative to `base_path`

    - format (`PlotFormat`, optional) – format

    - style (`str`, optional) – matplotlib style

    - colormaps (`list` of `matplotlib.colors.LinearSegmentedColormap`, optional) – colormaps

## 3.1.9.4. biosimulators_utils.plot.warnings module

Warnings for plots

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-01-20

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

exception biosimulators_utils.plot.warnings.IllogicalPlotWarning

  Bases: `biosimulators_utils.warnings.BioSimulatorsWarning`

  Warning that a plot is may be illogical (e.g., has mixed axes or scales)